@@ -1,24 +1,43 @@
 from pathlib import Path
 from typing import Callable, Dict, Optional, Type, Union
+import logging
 
 from .adapters.aiosqlite import AioSQLiteAdapter
 from .adapters.asyncpg import AsyncPGAdapter
-from .adapters.psycopg2 import PsycoPG2Adapter
-from .adapters.sqlite3 import SQLite3DriverAdapter
+from .adapters.psycopg import PsycoPGAdapter
+from .adapters.pyformat import PyFormatAdapter
+from .adapters.generic import GenericAdapter
+from .adapters.sqlite3 import SQLite3Adapter
+from .adapters.pg8000 import Pg8000Adapter
+from .adapters.apsw import APSWAdapter
 from .exceptions import SQLLoadException
 from .queries import Queries
 from .query_loader import QueryLoader
 from .types import DriverAdapterProtocol
 
+log = logging.getLogger(__name__)
 
 _ADAPTERS: Dict[str, Callable[..., DriverAdapterProtocol]] = {
-    "aiosqlite": AioSQLiteAdapter,
-    "asyncpg": AsyncPGAdapter,
-    "psycopg2": PsycoPG2Adapter,
-    "sqlite3": SQLite3DriverAdapter,
+    "aiosqlite": AioSQLiteAdapter,  # type: ignore
+    "apsw": APSWAdapter,
+    "asyncpg": AsyncPGAdapter,  # type: ignore
+    "mysqldb": PyFormatAdapter,
+    "mysql-connector": PyFormatAdapter,
+    "pg8000": Pg8000Adapter,
+    "psycopg": PsycoPGAdapter,
+    "psycopg2": PsycoPGAdapter,
+    "pymysql": PyFormatAdapter,
+    "sqlite3": SQLite3Adapter,
 }
 
 
+def register_adapter(name: str, adapter: Callable[..., DriverAdapterProtocol]):
+    """Register or override an adapter."""
+    if name in _ADAPTERS:
+        log.warning(f"overriding aiosql adapter {name}")
+    _ADAPTERS[name] = adapter
+
+
 def _make_driver_adapter(
     driver_adapter: Union[str, Callable[..., DriverAdapterProtocol]]
 ) -> DriverAdapterProtocol:
@@ -28,6 +47,15 @@ def _make_driver_adapter(
             driver_adapter = _ADAPTERS[driver_adapter]
         except KeyError:
             raise ValueError(f"Encountered unregistered driver_adapter: {driver_adapter}")
+    if callable(driver_adapter):
+        if hasattr(driver_adapter, "paramstyle"):  # pragma: no cover
+            style = getattr(driver_adapter, "paramstyle")
+            if style == "pyformat":
+                driver_adapter = PyFormatAdapter
+            elif style == "named":
+                driver_adapter = GenericAdapter
+            else:
+                raise ValueError(f"Unexpected driver_adapter: {driver_adapter} ({style})")
 
     return driver_adapter()
 
@@ -129,5 +157,5 @@ def from_path(
     elif path.is_dir():
         query_data_tree = query_loader.load_query_data_from_dir_path(path)
         return queries_cls(adapter).load_from_tree(query_data_tree)
-    else:
+    else:  # pragma: no cover
         raise SQLLoadException(f"The sql_path must be a directory or file, got {sql_path}")
