@@ -27,7 +27,7 @@ Pattern: Identifies SQL comments.
 
 var_pattern = re.compile(
     r'(?P<dblquote>"[^"]+")|'
-    r"(?P<quote>\'[^\']+\')|"
+    r"(?P<quote>\'[^\']*\')|"
     r"(?P<lead>[^:]):(?P<var_name>[\w-]+)(?P<trail>[^:]?)"
 )
 """
