@@ -99,16 +99,16 @@ def _make_ctx_mgr(fn: QueryFn) -> QueryFn:
 
 
 def _create_methods(query_datum: QueryDatum, is_aio: bool) -> List[Tuple[str, QueryFn]]:
+    """Internal function to feed add_queries."""
     fn = _make_sync_fn(query_datum)
     if is_aio:
         fn = _make_async_fn(fn)
 
     ctx_mgr = _make_ctx_mgr(fn)
 
-    # TODO: 4.0.0 release
+    # TODO in a later release?
     # The return can and should be simplified to List[QueryFn]
-    # i.e.
-    # return [fn, ctx_mgr] and [fn]
+    # i.e. "return [fn, ctx_mgr] and [fn]"
     if query_datum.operation_type == SQLOperationType.SELECT:
         return [(fn.__name__, fn), (ctx_mgr.__name__, ctx_mgr)]
     else:
@@ -158,9 +158,9 @@ class Queries:
     def add_queries(self, queries: List[Tuple[str, QueryFn]]):
         """Add query methods to `Queries` instance."""
         for query_name, fn in queries:
-            # TODO: Could be query_name = fn.__name__.rpartition(".")[2]
+            # TODO Could be query_name = fn.__name__.rpartition(".")[2]
             # if the interface here were changed to just queries being
-            # a List[QueryFn]
+            # a List[QueryFn] (see _create_methods)
             query_name = query_name.rpartition(".")[2]
             self.add_query(query_name, MethodType(fn, self))
 
